@@ -19,7 +19,7 @@ data.
 
 =head1 VERSION
 
-Version 0.0103
+Version 0.0104
 
 =cut
 
@@ -31,7 +31,7 @@ has '_test_files_names_map' => (is => "rw", isa => "HashRef",
     default => sub { +{} },
 );
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 =head1 SYNOPSIS
 
@@ -135,49 +135,13 @@ L<Test::Run::Obj>.
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-test-run-plugin-collectstats at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Run-Plugin-CollectStats>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Test::Run::Plugin::CollectStats
-
-You can also look for information at:
-
-=over 4
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-Run-Plugin-CollectStats>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Test-Run-Plugin-CollectStats>
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Run-Plugin-CollectStats>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Test-Run-Plugin-CollectStats>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Shlomi Fish, all rights reserved.
+Copyright 2007 Shlomi Fish.
 
-This program is released under the following license: MIT/X11.
+This program is released under the following license: MIT/Expat.
 
 =cut
 
